package cn.fw.valhalla.sdk.param;

import lombok.Data;

import javax.validation.constraints.NotEmpty;
import java.time.YearMonth;
import java.time.ZoneId;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * 应成交台数查询
 *
 * @author : kurisu
 * @version : 1.0
 * @className : ShouldBeCompletedQuery
 * @description : 应成交台数查询
 * @date : 2022-10-20 11:33
 */
@Data
public class ShouldBeCompletedQuery {
    /**
     * 跟进人员id
     */
    private Long userId;
    /**
     * 门店id
     */
    @NotEmpty(message = "门店不能为空")
    private Long[] shopId;
    /**
     * 跟进开始时间 [时间戳 默认为本月月初]
     */
    private Long startTime;
    /**
     * 跟进截止时间 [时间戳 默认为本月月底]
     */
    private Long endTime;

    public String getStartTime() {
        if (Objects.isNull(startTime)) {
            long second = YearMonth.now().atDay(1).atStartOfDay(ZoneId.systemDefault()).toEpochSecond();
            return String.valueOf(second);
        }
        String timeStr = String.valueOf(startTime);
        return timeStr.length() >= 10 ? timeStr.substring(0, 10) : timeStr;
    }

    public String getEndTime() {
        if (Objects.isNull(endTime)) {
            long second = YearMonth.now().atEndOfMonth().atStartOfDay(ZoneId.systemDefault()).toEpochSecond();
            return String.valueOf(second);
        }
        String timeStr = String.valueOf(endTime);
        return timeStr.length() >= 10 ? timeStr.substring(0, 10) : timeStr;
    }

    public List<Long> getShopId() {
        return Arrays.stream(shopId).collect(Collectors.toList());
    }

    public void setShopId(final Long... shopId) {
        this.shopId = shopId;
    }

    public void setShopId(final List<Long> shopIdList) {
        this.shopId = shopIdList.toArray(new Long[0]);
    }
}
